//
//  PDFViewController.m
//  PDFlib
//
//  Created by Friedhelm Brügge on 24.09.11.
//

#import "PDFViewController.h"



@implementation PDFViewController

@synthesize fileName = _fileName;
@synthesize testName = _testName;
@synthesize pdfData = _pdfData;


- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}


- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc]
        initWithBarButtonSystemItem:UIBarButtonSystemItemAction target:self action:@selector(showMenu:)];
    
    self.navigationItem.title=_testName;
    
    [_webView loadData:_pdfData MIMEType:@"application/pdf" textEncodingName:@"utf-8" baseURL:nil];
    
    return;
    
    NSURL *url = [NSURL fileURLWithPath:_fileName];
    NSURLRequest *urlRequest = [NSURLRequest requestWithURL:url];
    [_webView loadRequest:urlRequest]; 
    
}

// Show menu for iBooks and Email


-(void)showMenu: (id) button {
	
	UIActionSheet *actionSheet = [[UIActionSheet alloc] 
                                                    initWithTitle:nil
                                                    delegate:self 
                                                    cancelButtonTitle:@"Cancel"
                                                    destructiveButtonTitle:nil 
                                                    otherButtonTitles:
                                                    @"Send with Email",
						    @"Open in iBooks" ,
                                                    nil];
	actionSheet.actionSheetStyle = UIActionSheetStyleBlackOpaque;
	[actionSheet showInView:self.view];
	
}

- (void)actionSheet:(UIActionSheet *)actionSheet
clickedButtonAtIndex:(NSInteger)buttonIndex {
	
    switch (buttonIndex) {
        // send via Email
        case 0:
        {
            if ([MFMailComposeViewController canSendMail]) {
                [self displayComposerSheet];
            } else {
                UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Error occured" 
                        message:@"This device cannot send emails"
                        delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK" , nil];
                [alert show];
            }
        }
        break;
			
        // open in iBooks	
        case 1:
        {
            [self openIbooks];
            break;
        }
			
        default:
            break;
    }
}

// Displays an email composition interface inside the application. Populates all the Mail fields. 
-(void)displayComposerSheet 
{
	
	MFMailComposeViewController *picker = [[MFMailComposeViewController alloc] init];
	picker.mailComposeDelegate = self;
	
	[picker setSubject:[NSString stringWithFormat:@"This file was created with PDFlib example: %@", _testName]];
	
	// Attach an image to the email
	[picker addAttachmentData:_pdfData mimeType:@"application/pdf" fileName:[NSString stringWithFormat:@"%@.pdf", _testName]];
	
	// Fill out the email body text
	NSString *emailBody =  @"Hello,<br><br>this PDF file was created by the PDFlib library.<br><br><FONT SIZE=-2>More information about PDFlib: <a href=\"http://www.pdflib.com\">www.pdflib.com</font> ";
	[picker setMessageBody:emailBody isHTML:YES];
    
	[self presentModalViewController:picker animated:YES];
}


// Dismisses the email composition interface when users tap Cancel or Send. Proceeds to update the message field with the result of the operation.
- (void)mailComposeController:(MFMailComposeViewController*)controller didFinishWithResult:(MFMailComposeResult)result error:(NSError*)error 
{	
    [self dismissModalViewControllerAnimated:YES];
    
    NSString *text;
    // Notifies users about errors associated with the interface
    switch (result)
    {
        case MFMailComposeResultCancelled:
            text = @"Email has been cancelled" ;
            break;
        case MFMailComposeResultSaved:
            text = @"Email has been saved." ;
            break;
        case MFMailComposeResultSent:
            text = @"Email has beend sent" ;
            break;
        case MFMailComposeResultFailed:
            text = @"Unable to send e-mail" ;
            break;
        default:
            text = @"Email has not been sent" ;
            break;
    }
		
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:nil message:text
        delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK" , nil];
    [alert show];
}



// Open PDF document in iBooks

- (void) openIbooks {
    
    NSArray *dirPaths;
    NSString *documentsDir;
    dirPaths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    documentsDir = [dirPaths objectAtIndex:0];
    NSString *fileName = [NSString stringWithFormat:@"%@/%@.pdf", documentsDir, _testName];
    
    [_pdfData writeToFile:fileName atomically:NO];
    
    NSURL *url = [NSURL fileURLWithPath:fileName];
    UIDocumentInteractionController *docController = [UIDocumentInteractionController interactionControllerWithURL:url];
    
    docController.delegate = self;
    
    
    BOOL isValid = [docController presentOpenInMenuFromRect:CGRectMake(0, 0, 300, 300) inView:self.view animated:YES];
    
    
    if (!isValid) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Error occured" 
            message:@"Unable to open pdf document in iBooks." delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alert show];
    }
   
}


- (void)documentInteractionController:(UIDocumentInteractionController *)controller willBeginSendingToApplication:(NSString *)application {
    NSLog(@"willBegin");
}

- (void)documentInteractionController:(UIDocumentInteractionController *)controller didEndSendingToApplication:(NSString *)application {
    NSLog(@"didEnd");
}

- (void)documentInteractionControllerDidDismissOpenInMenu:(UIDocumentInteractionController *)controller {
    NSLog(@"dismiss");

}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
